@@ -1,21 +1,18 @@
-#
 #  testresources: extensions to python unittest to allow declaritive use
 #  of resources by test cases.
-#  Copyright (C) 2005  Robert Collins <robertc@robertcollins.net>
 #
-#  This program is free software; you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation; either version 2 of the License, or
-#  (at your option) any later version.
-#
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with this program; if not, write to the Free Software
-#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#  Copyright (c) 2005-2010 Testresources Contributors
+#  
+#  Licensed under either the Apache License, Version 2.0 or the BSD 3-clause
+#  license at the users choice. A copy of both licenses are available in the
+#  project source as Apache-2.0 and BSD. You may not use this file except in
+#  compliance with one of these two licences.
+#  
+#  Unless required by applicable law or agreed to in writing, software distributed
+#  under these licenses is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
+#  CONDITIONS OF ANY KIND, either express or implied.  See the license you chose
+#  for the specific language governing permissions and limitations under that
+#  license.
 #
 
 import testtools
@@ -101,6 +98,15 @@ class TestOptimisingTestSuite(testtools.TestCase):
         self.optimising_suite.addTest(suite)
         self.assertEqual([case], self.optimising_suite._tests)
 
+    def testAddTestOptimisingTestSuite(self):
+        # when adding an optimising test suite, it should be unpacked.
+        case = self.makeTestCase()
+        suite1 = testresources.OptimisingTestSuite([case])
+        suite2 = testresources.OptimisingTestSuite([case])
+        self.optimising_suite.addTest(suite1)
+        self.optimising_suite.addTest(suite2)
+        self.assertEqual([case, case], self.optimising_suite._tests)
+
     def testAddFlattensStandardSuiteStructure(self):
         # addTest will get rid of all unittest.TestSuite structure when adding
         # a test, no matter how much nesting is going on.
@@ -394,7 +400,7 @@ class TestCostGraph(testtools.TestCase):
         resource = self.makeResource()
         suite = testresources.OptimisingTestSuite()
         graph = suite._getGraph([frozenset()])
-        self.assertEqual({frozenset(): {frozenset(): 0}}, graph)
+        self.assertEqual({frozenset(): {}}, graph)
 
     def testTwoCasesInGraph(self):
         res1 = self.makeResource()
@@ -406,15 +412,15 @@ class TestCostGraph(testtools.TestCase):
 
         suite = testresources.OptimisingTestSuite()
         graph = suite._getGraph([no_resources, set1, set2])
-        self.assertEqual({no_resources: {no_resources: 0, set1: 2, set2: 1},
-                          set1: {no_resources: 2, set1: 0, set2: 1},
-                          set2: {no_resources: 1, set1: 1, set2: 0}}, graph)
+        self.assertEqual({no_resources: {set1: 2, set2: 1},
+                          set1: {no_resources: 2, set2: 1},
+                          set2: {no_resources: 1, set1: 1 }}, graph)
 
 
 class TestGraphStuff(testtools.TestCase):
 
     def setUp(self):
-
+        testtools.TestCase.setUp(self)
         class MockTest(unittest.TestCase):
             def __repr__(self):
                 """The representation is the tests name.
@@ -480,10 +486,15 @@ class TestGraphStuff(testtools.TestCase):
         return permutations
 
     def testBasicSortTests(self):
-        # Test every permutation of inputs, with equal cost resources and
-        # legacy tests.
+        # Test every permutation of inputs, with legacy tests.
+        # Cannot use equal costs because of the use of
+        # a 2*optimal heuristic for sorting: with equal
+        # costs the wrong sort order is < twice the optimal
+        # weight, and thus can be selected.
         resource_one = testresources.TestResource()
         resource_two = testresources.TestResource()
+        resource_two.setUpCost = 5
+        resource_two.tearDownCost = 5
         resource_three = testresources.TestResource()
 
         self.case1.resources = [
@@ -575,6 +586,43 @@ class TestGraphStuff(testtools.TestCase):
                 permutation.index(self.case3) < permutation.index(self.case4),
                 sorted.index(self.case3) < sorted.index(self.case4))
 
+    def testSortingTwelveIndependentIsFast(self):
+        # Given twelve independent resource sets, my patience is not exhausted.
+        managers = []
+        for pos in range(12):
+            managers.append(testresources.TestResourceManager())
+        # Add more sample tests
+        cases = [self.case1, self.case2, self.case3, self.case4]
+        for pos in range(5,13):
+            cases.append(
+                testtools.clone_test_with_new_id(cases[0], 'case%d' % pos))
+        # We care that this is fast in this test, so we don't need to have
+        # overlapping resource usage
+        for case, manager in zip(cases, managers):
+            case.resources = [('_resource', manager)]
+        # Any sort is ok, as long as its the right length :)
+        result = self.sortTests(cases)
+        self.assertEqual(12, len(result))
+
+    def testSortingTwelveOverlappingIsFast(self):
+        # Given twelve connected resource sets, my patience is not exhausted.
+        managers = []
+        for pos in range(12):
+            managers.append(testresources.TestResourceManager())
+        # Add more sample tests
+        cases = [self.case1, self.case2, self.case3, self.case4]
+        for pos in range(5,13):
+            cases.append(
+                testtools.clone_test_with_new_id(cases[0], 'case%d' % pos))
+        tempdir = testresources.TestResourceManager()
+        # give all tests a tempdir, enough to provoke a single partition in
+        # the current code.
+        for case, manager in zip(cases, managers):
+            case.resources = [('_resource', manager), ('tempdir', tempdir)]
+        # Any sort is ok, as long as its the right length :)
+        result = self.sortTests(cases)
+        self.assertEqual(12, len(result))
+
     def testSortConsidersDependencies(self):
         """Tests with different dependencies are sorted together."""
         # We test this by having two resources (one and two) that share a very
