@@ -1,21 +1,18 @@
-#
 #  testresources: extensions to python unittest to allow declaritive use
 #  of resources by test cases.
-#  Copyright (C) 2005  Robert Collins <robertc@robertcollins.net>
 #
-#  This program is free software; you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation; either version 2 of the License, or
-#  (at your option) any later version.
-#
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with this program; if not, write to the Free Software
-#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#  Copyright (c) 2005-2010 Testresources Contributors
+#  
+#  Licensed under either the Apache License, Version 2.0 or the BSD 3-clause
+#  license at the users choice. A copy of both licenses are available in the
+#  project source as Apache-2.0 and BSD. You may not use this file except in
+#  compliance with one of these two licences.
+#  
+#  Unless required by applicable law or agreed to in writing, software distributed
+#  under these licenses is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
+#  CONDITIONS OF ANY KIND, either express or implied.  See the license you chose
+#  for the specific language governing permissions and limitations under that
+#  license.
 #
 
 import testtools
@@ -67,7 +64,8 @@ class TestResourcedTestCase(testtools.TestCase):
     def testSetUpResourcesSingle(self):
         # setUpResources installs the resources listed in ResourcedTestCase.
         self.resourced_case.resources = [("foo", self.resource_manager)]
-        self.resourced_case.setUpResources()
+        testresources.setUpResources(self.resourced_case,
+            self.resourced_case.resources, None)
         self.assertEqual(self.resource, self.resourced_case.foo)
 
     def testSetUpResourcesMultiple(self):
@@ -75,7 +73,8 @@ class TestResourcedTestCase(testtools.TestCase):
         self.resourced_case.resources = [
             ('foo', self.resource_manager),
             ('bar', MockResource('bar_resource'))]
-        self.resourced_case.setUpResources()
+        testresources.setUpResources(self.resourced_case,
+            self.resourced_case.resources, None)
         self.assertEqual(self.resource, self.resourced_case.foo)
         self.assertEqual('bar_resource', self.resourced_case.bar)
 
@@ -86,14 +85,16 @@ class TestResourcedTestCase(testtools.TestCase):
         # Give the 'foo' resource access to a 'bar' resource
         self.resource_manager.resources.append(
             ('bar', MockResource('bar_resource')))
-        self.resourced_case.setUpResources()
+        testresources.setUpResources(self.resourced_case,
+            self.resourced_case.resources, None)
         self.assertEqual(resource, self.resourced_case.foo)
         self.assertEqual('bar_resource', self.resourced_case.foo.bar)
 
     def testSetUpUsesResource(self):
         # setUpResources records a use of each declared resource.
         self.resourced_case.resources = [("foo", self.resource_manager)]
-        self.resourced_case.setUpResources()
+        testresources.setUpResources(self.resourced_case,
+            self.resourced_case.resources, None)
         self.assertEqual(self.resource_manager._uses, 1)
 
     def testTearDownResourcesDeletesResourceAttributes(self):
