@@ -1,21 +1,18 @@
-
 #  testresources: extensions to python unittest to allow declaritive use
 #  of resources by test cases.
-#  Copyright (C) 2005  Robert Collins <robertc@robertcollins.net>
 #
-#  This program is free software; you can redistribute it and/or modify
-#  it under the terms of the GNU General Public License as published by
-#  the Free Software Foundation; either version 2 of the License, or
-#  (at your option) any later version.
-#
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#  GNU General Public License for more details.
-#
-#  You should have received a copy of the GNU General Public License
-#  along with this program; if not, write to the Free Software
-#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#  Copyright (c) 2005-2010 Testresources Contributors
+#  
+#  Licensed under either the Apache License, Version 2.0 or the BSD 3-clause
+#  license at the users choice. A copy of both licenses are available in the
+#  project source as Apache-2.0 and BSD. You may not use this file except in
+#  compliance with one of these two licences.
+#  
+#  Unless required by applicable law or agreed to in writing, software distributed
+#  under these licenses is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
+#  CONDITIONS OF ANY KIND, either express or implied.  See the license you chose
+#  for the specific language governing permissions and limitations under that
+#  license.
 #
 
 import testtools
@@ -389,3 +386,63 @@ class TestTestResource(testtools.TestCase):
         resource_manager.finishedWith(r)
         resource_manager.finishedWith(resource_manager._currentResource)
         self.assertEqual(expected, result._calls)
+
+
+class TestGenericResource(testtools.TestCase):
+
+    def test_default_uses_setUp_tearDown(self):
+        calls = []
+        class Wrapped:
+            def setUp(self):
+                calls.append('setUp')
+            def tearDown(self):
+                calls.append('tearDown')
+        mgr = testresources.GenericResource(Wrapped)
+        resource = mgr.getResource()
+        self.assertEqual(['setUp'], calls)
+        mgr.finishedWith(resource)
+        self.assertEqual(['setUp', 'tearDown'], calls)
+        self.assertIsInstance(resource, Wrapped)
+
+    def test_dependencies_passed_to_factory(self):
+        calls = []
+        class Wrapped:
+            def __init__(self, **args):
+                calls.append(args)
+            def setUp(self):pass
+            def tearDown(self):pass
+        class Trivial(testresources.TestResource):
+            def __init__(self, thing):
+                testresources.TestResource.__init__(self)
+                self.thing = thing
+            def make(self, dependency_resources):return self.thing
+            def clean(self, resource):pass
+        mgr = testresources.GenericResource(Wrapped)
+        mgr.resources = [('foo', Trivial('foo')), ('bar', Trivial('bar'))]
+        resource = mgr.getResource()
+        self.assertEqual([{'foo':'foo', 'bar':'bar'}], calls)
+        mgr.finishedWith(resource)
+
+    def test_setup_teardown_controllable(self):
+        calls = []
+        class Wrapped:
+            def start(self):
+                calls.append('setUp')
+            def stop(self):
+                calls.append('tearDown')
+        mgr = testresources.GenericResource(Wrapped,
+            setup_method_name='start', teardown_method_name='stop')
+        resource = mgr.getResource()
+        self.assertEqual(['setUp'], calls)
+        mgr.finishedWith(resource)
+        self.assertEqual(['setUp', 'tearDown'], calls)
+        self.assertIsInstance(resource, Wrapped)
+
+    def test_always_dirty(self):
+        class Wrapped:
+            def setUp(self):pass
+            def tearDown(self):pass
+        mgr = testresources.GenericResource(Wrapped)
+        resource = mgr.getResource()
+        self.assertTrue(mgr.isDirty())
+        mgr.finishedWith(resource)
